@@ -1507,7 +1507,7 @@ YFrameWindow *YWindowManager::manageClient(Window win, bool mapClient) {
     if (frame->affectsWorkArea())
         updateWorkArea();
     if (wmState() == wmRUNNING) {
-        if (doActivate == 1) {
+        if (doActivate == true) {
             frame->activateWindow(true);
             if (canManualPlace && opaqueMove)
                 frame->wmMove();
@@ -1713,6 +1713,8 @@ void YWindowManager::updateFullscreenLayer() { /// HACK !!!
             w->updateLayer();
         w = w->nextLayer();
     }
+    if (taskBar)
+        taskBar->updateFullscreen(getFocus() && getFocus()->isFullscreen());
 }
 
 void YWindowManager::restackWindows(YFrameWindow *) {
@@ -1738,6 +1740,9 @@ void YWindowManager::restackWindows(YFrameWindow *) {
         count++;
 #endif
 
+    if (taskBar)
+        count++;
+
     if (fLeftSwitch && fLeftSwitch->visible())
         count++;
 
@@ -1769,6 +1774,9 @@ void YWindowManager::restackWindows(YFrameWindow *) {
         p = p->prevPopup();
     }
 
+    if (taskBar)
+        w[i++] = taskBar->edgeTriggerWindow();;
+
     if (fLeftSwitch && fLeftSwitch->visible())
         w[i++] = fLeftSwitch->handle();
 
