@@ -163,7 +163,7 @@ void YFrameTitleBar::activate() {
         getFrame()->menuButton()->repaint();
 #endif
 #ifdef CONFIG_LOOK_PIXMAP
-    if (wmLook == lookPixmap || wmLook == lookMetal || wmLook == lookGtk) {
+    if (wmLook == lookPixmap || wmLook == lookMetal || wmLook == lookGtk || wmLook == lookFlat) {
         if (getFrame()->menuButton()) getFrame()->menuButton()->repaint();
         if (getFrame()->closeButton()) getFrame()->closeButton()->repaint();
         if (getFrame()->maximizeButton()) getFrame()->maximizeButton()->repaint();
@@ -274,6 +274,7 @@ void YFrameTitleBar::paint(Graphics &g, const YRect &/*r*/) {
 #ifdef CONFIG_LOOK_PIXMAP
     case lookPixmap:
     case lookMetal:
+    case lookFlat:
     case lookGtk: {
         int const pi(getFrame()->focused() ? 1 : 0);
 
@@ -383,7 +384,7 @@ void YFrameTitleBar::paint(Graphics &g, const YRect &/*r*/) {
 #ifdef CONFIG_SHAPED_DECORATION
 void YFrameTitleBar::renderShape(Pixmap shape) {
 #ifdef CONFIG_LOOK_PIXMAP
-    if (wmLook == lookPixmap || wmLook == lookMetal || wmLook == lookGtk) {
+    if (wmLook == lookPixmap || wmLook == lookMetal || wmLook == lookGtk || wmLook == lookFlat) {
         Graphics g(shape, getFrame()->width(), getFrame()->height());
 
         int onLeft(0);
@@ -396,7 +397,7 @@ void YFrameTitleBar::renderShape(Pixmap shape) {
                     onLeft = max(onLeft, (int)(b->x() + b->width()));
 
                     ref<YPixmap> pixmap = b->getImage(0);
-                    if (pixmap != null) {
+                    if (pixmap != null && b->getImage(1) != null ) { 
                         g.copyDrawable(pixmap->mask(), 0, 0,
                                        b->width(),
                                        b->height(),
@@ -413,7 +414,7 @@ void YFrameTitleBar::renderShape(Pixmap shape) {
                     onRight = min(onRight, b->x());
 
                     ref<YPixmap> pixmap = b->getImage(0);
-                    if (pixmap != null) {
+                    if ( pixmap != null && b->getImage(1) != null ) {
                         g.copyDrawable(pixmap->mask(), 0, 0,
                                        b->width(),
                                        b->height(),
